# Nxscli-np
![master workflow](https://github.com/railab/nxscli-np/actions/workflows/master.yml/badge.svg)

Numpy extension to Nxscli.

## Features

* Save data to NumPy files (`.npy`)
* NumPy `numpy.memmap()` support

